==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fAstore.h <==
// class soot.coffi.Instruction_Astore

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 702630811affac62 soot_coffi_Instruction__5fAstore
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fAstore_H_
#define _JC_soot_coffi_Instruction__5fAstore_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fAstore$sub_refs	_jc_soot_coffi_Instruction__5fAstore$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fAstore$sub_nonrefs	_jc_soot_coffi_Instruction__5fAstore$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAstore$refs	_jc_soot_coffi_Instruction__5fAstore$refs;
typedef struct _jc_soot_coffi_Instruction__5fAstore$nonrefs	_jc_soot_coffi_Instruction__5fAstore$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAstore$object	_jc_soot_coffi_Instruction__5fAstore$object;

typedef const struct _jc_soot_coffi_Instruction__5fAstore$vmethods	_jc_soot_coffi_Instruction__5fAstore$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fAstore$vtable	_jc_soot_coffi_Instruction__5fAstore$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fAstore$vtype	_jc_soot_coffi_Instruction__5fAstore$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fAstore$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fAstore$object *);

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fAstore$method$getLocalNumber$7929c8070e3cb45d(_jc_env *, struct _jc_soot_coffi_Instruction__5fAstore$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fAstore$method_info$getLocalNumber$7929c8070e3cb45d;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fAstore$vmethods {
	jint	(*getLocalNumber$7929c8070e3cb45d)(_jc_env *, struct _jc_soot_coffi_Instruction__5fAstore$object *);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fAstore$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fAstore$vmethods	soot_coffi_Instruction__5fAstore;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fAstore$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fAstore$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAstore$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAstore$refs {
    _jc_soot_coffi_Instruction__5fAstore$sub_refs	soot_coffi_Instruction__5fAstore;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAstore$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAstore$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fAstore$sub_nonrefs	soot_coffi_Instruction__5fAstore;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fAstore$object {
	_jc_soot_coffi_Instruction__5fAstore$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fAstore$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fAstore$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fAstore$vtype _jc_soot_coffi_Instruction__5fAstore$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fAstore, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fAstore$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fAstore_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fAstore.h <==
// class soot.coffi.Instruction_Astore

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 702630811affac62 soot_coffi_Instruction__5fAstore
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fAstore_H_
#define _JC_soot_coffi_Instruction__5fAstore_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fAstore$sub_refs	_jc_soot_coffi_Instruction__5fAstore$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fAstore$sub_nonrefs	_jc_soot_coffi_Instruction__5fAstore$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAstore$refs	_jc_soot_coffi_Instruction__5fAstore$refs;
typedef struct _jc_soot_coffi_Instruction__5fAstore$nonrefs	_jc_soot_coffi_Instruction__5fAstore$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAstore$object	_jc_soot_coffi_Instruction__5fAstore$object;

typedef const struct _jc_soot_coffi_Instruction__5fAstore$vmethods	_jc_soot_coffi_Instruction__5fAstore$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fAstore$vtable	_jc_soot_coffi_Instruction__5fAstore$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fAstore$vtype	_jc_soot_coffi_Instruction__5fAstore$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fAstore$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fAstore$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fAstore$method$getLocalNumber$7929c8070e3cb45d(_jc_env *, struct _jc_soot_coffi_Instruction__5fAstore$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fAstore$method_info$getLocalNumber$7929c8070e3cb45d;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fAstore$vmethods {
	jint	(*getLocalNumber$7929c8070e3cb45d)(_jc_env *, struct _jc_soot_coffi_Instruction__5fAstore$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fAstore$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fAstore$vmethods	soot_coffi_Instruction__5fAstore;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fAstore$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fAstore$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAstore$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAstore$refs {
    _jc_soot_coffi_Instruction__5fAstore$sub_refs	soot_coffi_Instruction__5fAstore;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAstore$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAstore$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fAstore$sub_nonrefs	soot_coffi_Instruction__5fAstore;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fAstore$object {
	_jc_soot_coffi_Instruction__5fAstore$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fAstore$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fAstore$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fAstore$vtype _jc_soot_coffi_Instruction__5fAstore$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fAstore, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fAstore$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fAstore_H_ */
